.. note::

    The generated report can be:

    - displayed in a Notebook,
    - opened in a browser using the ``.open_in_browser()`` method,
    - or saved to a file using the ``.save_as_html(output_filepath)`` method.
